class Filter():
    def __init__(self):
        pass


class BatchFilter():
    def __init__(self):
        pass


class BlendFilter():
    def __init__(self):
        pass


class BlurFilter():
    def __init__(self):
        pass


class ShadowFilter():
    def __init__(self):
        pass


class NoiseFilter():
    def __init__(self):
        pass


class ConvolveFilter():
    def __init__(self):
        pass


class DisplaceFilter():
    def __init__(self):
        pass
